@@ -1,24 +1,43 @@
+#ifndef DGGRIDR
+#define DGGRIDR
+#endif
+/*******************************************************************************
+    Copyright (C) 2021 Kevin Sahr
+
+    This file is part of DGGRID.
+
+    DGGRID is free software: you can redistribute it and/or modify
+    it under the terms of the GNU Affero General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
+
+    DGGRID is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU Affero General Public License for more details.
+
+    You should have received a copy of the GNU Affero General Public License
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
+*******************************************************************************/
 ////////////////////////////////////////////////////////////////////////////////
 //
 // DgOutputStream.h: DgOutputStream class definition
 //
 //   This class provides wrappers around some basic output stream functionality
-//   to increase ease of use. 
-//
-// Version 6.2 - Kevin Sahr, 9/10/13
+//   to increase ease of use.
 //
 ////////////////////////////////////////////////////////////////////////////////
 
 #ifndef DGOUTPUTSTREAM_H
 #define DGOUTPUTSTREAM_H
 
-#include <string>
+#include "DgBase.h"
+
 #include <fstream>
+#include <string>
 
 using namespace std;
 
-#include "DgBase.h"
-
 ////////////////////////////////////////////////////////////////////////////////
 class DgOutputStream : public ofstream, public DgBase {
 
@@ -27,7 +46,7 @@ class DgOutputStream : public ofstream, public DgBase {
       DgOutputStream (void) : DgBase ("DgOutputStream") {}
 
       DgOutputStream (const string& fileName,
-                      const string& suffix    = string(""), 
+                      const string& suffix    = string(""),
                       DgReportLevel failLevel = DgBase::Fatal);
 
      ~DgOutputStream (void) { close(); }
