@@ -1,5 +1,11 @@
+#ifndef DGGRIDR
+#define DGGRIDR
+#endif
 /* determine small q */
-#include <cmath>
+#ifndef lint
+//static const char SCCSID[]="@(#)pj_qsfn.c	4.3	93/06/12	GIE	REL";
+#endif
+#include <math.h>
 
 # define EPSILON 1.0e-7
 	long double
@@ -9,7 +15,7 @@ pj_qsfn(long double sinphi, long double e, long double one_es) {
 	if (e >= EPSILON) {
 		con = e * sinphi;
 		return (one_es * (sinphi / (1. - con * con) -
-		   (.5 / e) * std::log ((1. - con) / (1. + con))));
+		   (.5 / e) * log ((1. - con) / (1. + con))));
 	} else
 		return (sinphi + sinphi);
 }
